# PaymentServiceSnapshot

An active, configured payment service.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | The ID of this payment service. | [optional] 
**type** | **str** | The type of this resource. | [optional]  if omitted the server will use the default value of "payment-service"
**payment_service_definition_id** | **str** | The ID of the payment service definition used to create this service.  | [optional] 
**method** | **object** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


